:mod:`fugw.solvers`
===================

Under the hood, classes in :mod:`fugw.mappings` call solvers
implemented in :mod:`fugw.solvers`.

.. toctree::

   solvers.FUGWSolver.rst
   solvers.FUGWSparseSolver.rst
